@@ -1,4 +1,6 @@
-import numpy as np
+__version__ = "0.10.2"
+
+from autograd import numpy as np
 
 from surpyval.utils import (
     xcn_sort,
@@ -9,6 +11,7 @@ from surpyval.utils import (
     xcnt_to_xrd,
     fsli_to_xcn,
     fsl_to_xcn,
+    fs_to_xcn,
     fs_to_xrd,
     round_sig,
     xcn_to_fs
@@ -37,6 +40,10 @@ from surpyval.nonparametric import (
     Turnbull
 )
 
+from surpyval.regression import (
+    CoxPH
+)
+
 NUM = np.float64
 TINIEST = np.finfo(np.float64).tiny
 EPS = np.sqrt(np.finfo(NUM).eps)
