@@ -1,5 +1,4 @@
 import numpy as np
-from surpyval.utils import xcnt_to_xrd
 from surpyval.nonparametric.nonparametric_fitter import NonParametricFitter
 
 
@@ -13,7 +12,7 @@ def fh_h(r_i, d_i):
     return out
 
 
-def fh(r, d):
+def fleming_harrington(r, d):
     Y = np.array([fh_h(r_i, d_i) for r_i, d_i in zip(r, d)])
     H = Y.cumsum()
     H[np.isnan(H)] = np.inf
@@ -21,13 +20,6 @@ def fh(r, d):
     return R
 
 
-def fleming_harrington(x, c, n, t):
-    xrd = xcnt_to_xrd(x, c, n, t)
-    out = {k: v for k, v in zip(['x', 'r', 'd'], xrd)}
-    out['R'] = fh(out['r'], out['d'])
-    return out
-
-
 class FlemingHarrington_(NonParametricFitter):
     r"""
     Fleming-Harrington estimation of survival distribution.
