@@ -1,13 +1,13 @@
 import numpy as np
 from surpyval.nonparametric.nonparametric_fitter import NonParametricFitter
-from .nelson_aalen import na
-from .kaplan_meier import km
-from .fleming_harrington import fh
+from .nelson_aalen import nelson_aalen as na
+from .kaplan_meier import kaplan_meier as km
+from .fleming_harrington import fleming_harrington as fh
 
 
 def turnbull(x, c, n, t, estimator='Fleming-Harrington'):
     bounds = np.unique(np.concatenate([np.unique(x), np.unique(t)]))
-    bounds = np.sort(np.concatenate([bounds, np.unique(x[c==0])]))
+    bounds = np.sort(np.concatenate([bounds, np.unique(x[c == 0])]))
     N = n.sum()
 
     if x.ndim == 1:
