@@ -1,4 +1,4 @@
-import autograd.numpy as np
+from surpyval import np
 from scipy.stats import uniform
 from scipy.special import ndtri as z
 from autograd.scipy.stats import norm
