@@ -8,9 +8,12 @@ from scipy.special import ndtri as z
 from surpyval import nonparametric as nonp
 from copy import deepcopy, copy
 from matplotlib.ticker import FixedLocator
+from autograd import elementwise_grad
+
 
 CB_COLOUR = "#e94c54"
 
+
 def _round_vals(x):
     not_different = True
     i = 1
@@ -98,7 +101,7 @@ class Parametric():
         else:
             return "Unable to fit values"
 
-    def param_cb(self, name, alpha=0.05, bound="two-sided"):
+    def param_cb(self, name, alpha_ci=0.05, bound="two-sided"):
         """
         Method to calculate the confidence bound on a parameter.
         """
@@ -386,7 +389,9 @@ class Parametric():
         0.00025840046151723767
         """
         x = np.array(x)
-        cs = np.array(self.dist.cs(x - self.gamma, X - self.gamma, *self.params))
+        cs = np.array(self.dist.cs(x - self.gamma,
+                                   X - self.gamma,
+                                   *self.params))
         cs[cs > 1.] = 1
         return cs
 
@@ -594,6 +599,7 @@ class Parametric():
             the selected function at x
 
         """
+        t = np.atleast_1d(t)
         if self.method != 'MLE':
             raise Exception('Only MLE has confidence bounds')
 
@@ -603,7 +609,7 @@ class Parametric():
         old_err_state = np.seterr(all='ignore')
 
         if hasattr(self.dist, 'R_cb'):
-            def R_cb(x):
+            def R_cb(x, bound=bound):
                 return self.dist.R_cb(x - self.gamma,
                                       *self.params,
                                       hess_inv,
@@ -611,7 +617,7 @@ class Parametric():
                                       bound=bound)
 
         else:
-            def R_cb(x):
+            def R_cb(x, bound=bound):
                 def sf_func(params):
                     return self.dist.sf(x - self.gamma, *params)
                 jac = np.atleast_2d(jacobian(sf_func)(np.array(self.params)))
@@ -640,30 +646,54 @@ class Parametric():
                 R_cb = R_hat / (R_hat + (1 - R_hat) * np.exp(exponent))
                 return R_cb.T
 
-        # Default cb is R
-        cb = R_cb(t)
+        # Reverse for ff and F
+        if on in ['ff', 'F', 'Hf', 'hf', 'df'] and bound == 'lower':
+            bound = 'upper'
+        elif on in ['ff', 'F', 'Hf', 'hf', 'df'] and bound == 'upper':
+            bound = 'lower'
 
         if (on == 'ff') or (on == 'F'):
+            cb = R_cb(t, bound=bound)
             cb = 1. - cb
-
+        elif (on == 'sf') or (on == 'R'):
+            cb = R_cb(t, bound=bound)
+            if bound == 'two-sided':
+                cb = np.fliplr(cb)
         elif on == 'Hf':
+            cb = R_cb(t, bound=bound)
             cb = -np.log(cb)
-
         elif on == 'hf':
             def cb_hf(x):
                 out = []
-                for v in x:
-                    out.append(jacobian(lambda x: -np.log(R_cb(x)))(v))
-                return np.concatenate(out)
+                func = lambda x: -np.log(R_cb(x, bound=bound))
+                if bound == 'two-sided':
+                    jac = jacobian(func)
+                    cbs = [jac(np.array([v])).flatten() for v in x]
+                    return np.vstack(cbs)
+                else:
+                    grad = elementwise_grad(func)
+                    return grad(x)
+
             cb = cb_hf(t)
 
         elif on == 'df':
             def cb_df(x):
                 out = []
-                for v in x:
-                    out.append(jacobian(lambda x: (-np.log(R_cb(x)))(v)
-                                        * self.sf(v)))
-                return np.concatenate(out)
+                
+                func = lambda x: (-np.log(R_cb(x, bound)))
+                
+                if bound == 'two-sided':
+                    jac = jacobian(func)
+                    cbs = [jac(np.array([v])).flatten() for v in x]
+                    cbs = np.vstack(cbs)
+                    cbs = cbs * self.sf(x).reshape(-1, 1)
+                else:
+                    grad = elementwise_grad(func)
+                    cbs = grad(x)
+                    cbs = cbs * self.sf(x)
+
+                return cbs
+
             cb = cb_df(t)
 
         np.seterr(**old_err_state)
@@ -933,7 +963,10 @@ class Parametric():
             'F': F
         }
 
-    def plot(self, heuristic='Nelson-Aalen', plot_bounds=True, alpha_ci=0.05, ax=None):
+    def plot(self, heuristic='Nelson-Aalen',
+             plot_bounds=True,
+             alpha_ci=0.05,
+             ax=None):
         r"""
         A method to do a probability plot
 
@@ -972,15 +1005,16 @@ class Parametric():
         """
         if ax is None:
             ax = plt.gcf().gca()
- 
+
         if not hasattr(self, 'params'):
             raise Exception("Can't plot model that failed to fit")
- 
+
         if self.method == 'given parameters':
-            raise Exception("Can't plot model that was given parameters and no data")
-        
+            detail = "Can't plot model that was given parameters and no data"
+            raise Exception(detail)
+
         d = self.get_plot_data(heuristic=heuristic, alpha_ci=alpha_ci)
- 
+
         # Set limits and scale
         ax.set_ylim([d['y_scale_min'], d['y_scale_max']])
         ax.set_xscale(d['x_scale'])
@@ -993,21 +1027,21 @@ class Parametric():
         ax.yaxis.set_minor_locator(FixedLocator(np.linspace(0, 1, 51)))
         ax.set_xticks(d['x_ticks'])
         ax.set_xticklabels(d['x_ticks_labels'])
- 
+
         if d['x_scale'] == 'log':
             ax.set_xticks(d['x_minor_ticks'], minor=True)
             ax.set_xticklabels([], minor=True)
-        
+
         ax.grid(b=True, which='major', color='g', alpha=0.4, linestyle='-')
         ax.grid(b=True, which='minor', color='g', alpha=0.1, linestyle='-')
- 
+
         ax.set_title('{} Probability Plot'.format(self.dist.name))
         ax.set_ylabel('CDF')
         ax.scatter(d['x_'], d['F'])
- 
+
         ax.set_xlim([d['x_scale_min'], d['x_scale_max']])
         if plot_bounds & (len(d['cbs']) != 0):
             ax.plot(d['x_model'], d['cbs'], color=CB_COLOUR)
-        
+
         ax.plot(d['x_model'], d['cdf'], color='k', linestyle='--')
         return ax
